@@ -95,6 +95,8 @@ std::vector<int> DNA::getAlias(int state) const throw (BadIntException)
     throw BadIntException(state, "DNA::getAlias(int): Specified base unknown.");
 	vector<int> v;
   const NucleicAlphabetState& st = getState(state);
+  if (state == -1)
+    v.push_back(-1);
   if (st.getBinaryCode() & 1)
     v.push_back(0);
   if (st.getBinaryCode() & 2)
@@ -124,8 +126,8 @@ std::vector<std::string> DNA::getAlias(const std::string& state) const throw (Ba
 
 int DNA::getGeneric(const std::vector<int>& states) const throw (BadIntException)
 {
-  char v = 0;
-  for (unsigned int i = 0 ; i < states.size() ; ++i) {
+  int v = 0;
+  for (size_t i = 0 ; i < states.size() ; ++i) {
     if (!isIntInAlphabet(states[i])) throw BadIntException(states[i], "DNA::getGeneric(const vector<int>& states): Specified base unknown.");
     v |= getState(states[i]).getBinaryCode();
   }
