@@ -39,10 +39,28 @@
  */
 
 #include "SequenceApplicationTools.h"
+#include "../Alphabet/BinaryAlphabet.h"
+#include "../Alphabet/DefaultAlphabet.h"
+#include "../Alphabet/EchinodermMitochondrialCodonAlphabet.h"
+#include "../Alphabet/InvertebrateMitochondrialCodonAlphabet.h"
+#include "../Alphabet/StandardCodonAlphabet.h"
+#include "../Alphabet/VertebrateMitochondrialCodonAlphabet.h"
+#include "../Alphabet/YeastMitochondrialCodonAlphabet.h"
+#include "../Alphabet/AlphabetTools.h"
+#include "../GeneticCode/EchinodermMitochondrialGeneticCode.h"
+#include "../GeneticCode/InvertebrateMitochondrialGeneticCode.h"
+#include "../GeneticCode/StandardGeneticCode.h"
+#include "../GeneticCode/VertebrateMitochondrialGeneticCode.h"
+#include "../GeneticCode/YeastMitochondrialGeneticCode.h"
+#include "../Io/BppOSequenceReaderFormat.h"
+#include "../Io/BppOAlignmentReaderFormat.h"
+#include "../Io/BppOSequenceWriterFormat.h"
+#include "../Io/BppOAlignmentWriterFormat.h"
+#include "../Io/BppOAlphabetIndex1Format.h"
+#include "../Io/BppOAlphabetIndex2Format.h"
+#include "../Io/MaseTools.h"
 #include "../SiteTools.h"
 #include "../SequenceTools.h"
-#include "../Alphabet.all"
-#include "../Io.all"
 #include <Bpp/App/ApplicationTools.h>
 #include <Bpp/Text/TextTools.h>
 #include <Bpp/Text/KeyvalTools.h>
@@ -80,30 +98,34 @@ Alphabet* SequenceApplicationTools::getAlphabet(
     flag = 1;
   }
   else if (alphabet == "RNY")
-    {
-      if (args.find("letter") == args.end())
-        throw Exception("Missing letter alphabet for RNY alphabet");
-      alphabet = args["letter"];
-      flag = 2;
-    }
+  {
+    if (args.find("letter") == args.end())
+      throw Exception("Missing letter alphabet for RNY alphabet");
+    alphabet = args["letter"];
+    flag = 2;
+  }
 
 
   if (alphabet == "Binary")
     chars = new BinaryAlphabet();
-  else if (alphabet == "DNA") {
+  else if (alphabet == "DNA")
+  {
     bool mark = ApplicationTools::getBooleanParameter("bangAsGap", args, false, "", true, false);
     chars = new DNA(mark);
-  } else if (alphabet == "RNA") {
+  }
+  else if (alphabet == "RNA")
+  {
     bool mark = ApplicationTools::getBooleanParameter("bangAsGap", args, false, "", true, false);
     chars = new RNA(mark);
-  } else if (alphabet == "Protein")
+  }
+  else if (alphabet == "Protein")
     chars = new ProteicAlphabet();
   else if (allowGeneric && alphabet == "Generic")
     chars = new DefaultAlphabet();
   else if (alphabet == "Codon")
   {
     if (args.find("letter") == args.end())
-      throw Exception("Missing alphabet in Codon : " + alphabet);
+      throw Exception("Missing 'letter' argument in Codon :" + alphabet);
 
     string alphnDesc = ApplicationTools::getStringParameter("letter", args, "RNA");
     string alphn;
@@ -111,13 +133,17 @@ Alphabet* SequenceApplicationTools::getAlphabet(
     KeyvalTools::parseProcedure(alphnDesc, alphn, alphnArgs);
 
     NucleicAlphabet* pnalph;
-    if (alphn == "RNA") {
+    if (alphn == "RNA")
+    {
       bool mark = ApplicationTools::getBooleanParameter("bangAsGap", alphnArgs, false, "", true, false);
       pnalph = new RNA(mark);
-    } else if (alphn == "DNA") {
+    }
+    else if (alphn == "DNA")
+    {
       bool mark = ApplicationTools::getBooleanParameter("bangAsGap", alphnArgs, false, "", true, false);
       pnalph = new DNA(mark);
-    } else
+    }
+    else
       throw Exception("Alphabet not known in Codon : " + alphn);
 
     string type = ApplicationTools::getStringParameter("type", args, "Standard");
@@ -130,6 +156,8 @@ Alphabet* SequenceApplicationTools::getAlphabet(
       chars = new StandardCodonAlphabet(pnalph);
     else if (type == "VertebrateMitochondrial")
       chars = new VertebrateMitochondrialCodonAlphabet(pnalph);
+    else if (type == "YeastMitochondrial")
+      chars = new YeastMitochondrialCodonAlphabet(pnalph);
     else
       throw Exception("Unknown Alphabet : " + alphabet);
     alphabet = alphabet + "(" + alphn + ")";
@@ -148,15 +176,15 @@ Alphabet* SequenceApplicationTools::getAlphabet(
     alphabet = "Word(" + al + ")";
   }
   else if (flag == 2)
+  {
+    if (AlphabetTools::isNucleicAlphabet(chars))
     {
-      if (AlphabetTools::isNucleicAlphabet(chars))
-        {
-          chars = new RNY(*(dynamic_cast<NucleicAlphabet*>(chars)));
-          alphabet = "RNY(" + alphabet + ")";
-        }
-      else
-        throw Exception("RNY needs a Nucleic Alphabet, instead of " + alphabet);
+      chars = new RNY(*(dynamic_cast<NucleicAlphabet*>(chars)));
+      alphabet = "RNY(" + alphabet + ")";
     }
+    else
+      throw Exception("RNY needs a Nucleic Alphabet, instead of " + alphabet);
+  }
 
 
   if (verbose)
@@ -188,25 +216,18 @@ GeneticCode* SequenceApplicationTools::getGeneticCode(
 
 /******************************************************************************/
 
-AlphabetIndex2<double>* SequenceApplicationTools::getAADistance(const string& description)
+AlphabetIndex1* SequenceApplicationTools::getAlphabetIndex1(const Alphabet* alphabet, const string& description, const string& message, bool verbose)
 throw (Exception)
 {
-  AlphabetIndex2<double>* distance = 0;
-  if (description == "BLOSUM50")
-    distance = new BLOSUM50();
-  else if (description == "GranthamAAChemicalDistance")
-  {
-    distance = new GranthamAAChemicalDistance();
-    ((GranthamAAChemicalDistance*) distance)->setSymmetric(1);
-  }
-  else if (description == "MiyataAAChemicalDistance")
-  {
-    distance = new MiyataAAChemicalDistance();
-    ((MiyataAAChemicalDistance*)distance)->setSymmetric(1);
-  }
-  else
-    throw Exception("Unknown AA distance: " + description);
-  return distance;
+  BppOAlphabetIndex1Format reader(alphabet, message, verbose);
+  return reader.read(description);
+}
+
+AlphabetIndex2* SequenceApplicationTools::getAlphabetIndex2(const Alphabet* alphabet, const string& description, const string& message, bool verbose)
+throw (Exception)
+{
+  BppOAlphabetIndex2Format reader(alphabet, message, verbose);
+  return reader.read(description);
 }
 
 /******************************************************************************/
@@ -219,90 +240,14 @@ SequenceContainer* SequenceApplicationTools::getSequenceContainer(
 {
   string sequenceFilePath = ApplicationTools::getAFilePath("input.sequence.file", params, true, true, suffix, suffixIsOptional);
   string sequenceFormat = ApplicationTools::getStringParameter("input.sequence.format", params, "Fasta()", suffix, suffixIsOptional);
-  string format = "";
-  map<string, string> args;
-  KeyvalTools::parseProcedure(sequenceFormat, format, args);
+  BppOSequenceReaderFormat bppoReader(verbose);
+  auto_ptr<ISequence> iSeq(bppoReader.read(sequenceFormat));
   if (verbose)
-    ApplicationTools::displayResult("Sequence format " + suffix, format);
-  auto_ptr<ISequence> iSeq;
-  if (format == "Mase")
   {
-    iSeq.reset(new Mase());
-  }
-  else if (format == "Phylip")
-  {
-    bool sequential = true, extended = true;
-    string split = "  ";
-    if (args.find("order") != args.end())
-    {
-      if (args["order"] == "sequential")
-        sequential = true;
-      else if (args["order"] == "interleaved")
-        sequential = false;
-      else
-        ApplicationTools::displayWarning("Argument '" +
-                                         args["order"] +
-                                         "' for argument 'Phylip#order' is unknown. " +
-                                         "Default used instead: sequential.");
-    }
-    else
-      ApplicationTools::displayWarning("Argument 'Phylip#order' not found. Default used instead: sequential.");
-    if (args.find("type") != args.end())
-    {
-      if (args["type"] == "extended")
-      {
-        extended = true;
-        split = ApplicationTools::getStringParameter("split", args, "spaces", "", true, false);
-        if (split == "spaces")
-          split = "  ";
-        else if (split == "tab")
-          split = "\t";
-        else
-          throw Exception("Unknown option for Phylip#split: " + split);
-      }
-      else if (args["type"] == "classic")
-        extended = false;
-      else
-        ApplicationTools::displayWarning("Argument '" +
-                                         args["type"] + "' for parameter 'Phylip#type' is unknown. " +
-                                         "Default used instead: extended.");
-    }
-    else
-      ApplicationTools::displayWarning("Argument 'Phylip#type' not found. Default used instead: extended.");
-    iSeq.reset(new Phylip(extended, sequential, 100, true, split));
-  }
-  else if (format == "Fasta")
-  {
-    bool strictNames = ApplicationTools::getBooleanParameter("strict_names", args, false, "", true, false);
-    bool extended    = ApplicationTools::getBooleanParameter("extended", args, false, "", true, false);
-    iSeq.reset(new Fasta(100, true, extended, strictNames));
-  }
-  else if (format == "Clustal")
-  {
-    unsigned int extraSpaces = ApplicationTools::getParameter<unsigned int>("extraSpaces", args, 0, "", true, false);
-    iSeq.reset(new Clustal(true, extraSpaces));
-  }
-  else if (format == "Dcse")
-  {
-    iSeq.reset(new DCSE());
-  }
-  else if (format == "GenBank")
-  {
-    iSeq.reset(reinterpret_cast<ISequence*>(new GenBank())); // This is required to remove a strict-aliasing warning in gcc 4.4
-  }
-  else if (format == "Nexus")
-  {
-    iSeq.reset(new NexusIOSequence());
-  }
-  else
-  {
-    ApplicationTools::displayError("Unknown sequence format.");
-    exit(-1);
-  }
-  SequenceContainer* sequences = iSeq->read(sequenceFilePath, alpha);
-
-  if (verbose)
     ApplicationTools::displayResult("Sequence file " + suffix, sequenceFilePath);
+    ApplicationTools::displayResult("Sequence format " + suffix, iSeq->getFormatName());
+  }
+  SequenceContainer* sequences = iSeq->readSequences(sequenceFilePath, alpha);
 
   return sequences;
 }
@@ -318,89 +263,22 @@ VectorSiteContainer* SequenceApplicationTools::getSiteContainer(
 {
   string sequenceFilePath = ApplicationTools::getAFilePath("input.sequence.file", params, true, true, suffix, suffixIsOptional);
   string sequenceFormat = ApplicationTools::getStringParameter("input.sequence.format", params, "Fasta()", suffix, suffixIsOptional);
-  string format = "";
-  map<string, string> args;
-  KeyvalTools::parseProcedure(sequenceFormat, format, args);
-
+  BppOAlignmentReaderFormat bppoReader(verbose);
+  auto_ptr<IAlignment> iAln(bppoReader.read(sequenceFormat));
+  map<string, string> args(bppoReader.getUnparsedArguments());
   if (verbose)
-    ApplicationTools::displayResult("Sequence format " + suffix, format);
-  auto_ptr<ISequence> iSeq;
-  if (format == "Mase")
   {
-    iSeq.reset(new Mase());
-  }
-  else if (format == "Phylip")
-  {
-    bool sequential = true, extended = true;
-    string split = "  ";
-    if (args.find("order") != args.end())
-    {
-      if (args["order"] == "sequential")
-        sequential = true;
-      else if (args["order"] == "interleaved")
-        sequential = false;
-      else
-        ApplicationTools::displayWarning("Argument '" +
-                                         args["order"] +
-                                         "' for argument 'Phylip#order' is unknown. " +
-                                         "Default used instead: sequential.");
-    }
-    else
-      ApplicationTools::displayWarning("Argument 'Phylip#order' not found. Default used instead: sequential.");
-    if (args.find("type") != args.end())
-    {
-      if (args["type"] == "extended")
-      {
-        extended = true;
-        split = ApplicationTools::getStringParameter("split", args, "spaces", "", true, false);
-        if (split == "spaces")
-          split = "  ";
-        else if (split == "tab")
-          split = "\t";
-        else
-          throw Exception("Unknown option for Phylip#split: " + split);
-      }
-      else if (args["type"] == "classic")
-        extended = false;
-      else
-        ApplicationTools::displayWarning("Argument '" +
-                                         args["type"] + "' for parameter 'Phylip#type' is unknown. " +
-                                         "Default used instead: extended.");
-    }
-    else
-      ApplicationTools::displayWarning("Argument 'Phylip#type' not found. Default used instead: extended.");
-    iSeq.reset(new Phylip(extended, sequential, 100, true, split));
-  }
-  else if (format == "Fasta")
-  {
-    bool strictNames = ApplicationTools::getBooleanParameter("strict_names", args, false, "", true, false);
-    bool extended    = ApplicationTools::getBooleanParameter("extended", args, false, "", true, false);
-    iSeq.reset(new Fasta(100, true, extended, strictNames));
-  }
-  else if (format == "Clustal")
-  {
-    unsigned int extraSpaces = ApplicationTools::getParameter<unsigned int>("extraSpaces", args, 0, "", true, false);
-    iSeq.reset(new Clustal(true, extraSpaces));
-  }
-  else if (format == "Dcse")
-  {
-    iSeq.reset(new DCSE());
-  }
-  else if (format == "Nexus")
-  {
-    iSeq.reset(new NexusIOSequence());
-  }
-  else
-  {
-    throw Exception("Unknown sequence format: " + format);
+    ApplicationTools::displayResult("Sequence file " + suffix, sequenceFilePath);
+    ApplicationTools::displayResult("Sequence format " + suffix, iAln->getFormatName());
   }
+
   const Alphabet* alpha2;
   if (AlphabetTools::isRNYAlphabet(alpha))
     alpha2 = &dynamic_cast<const RNY*>(alpha)->getLetterAlphabet();
   else
     alpha2 = alpha;
 
-  const SequenceContainer* seqCont = iSeq->read(sequenceFilePath, alpha2);
+  const SequenceContainer* seqCont = iAln->readAlignment(sequenceFilePath, alpha2);
 
   VectorSiteContainer* sites2 = new VectorSiteContainer(*dynamic_cast<const OrderedSequenceContainer*>(seqCont));
   delete seqCont;
@@ -408,22 +286,20 @@ VectorSiteContainer* SequenceApplicationTools::getSiteContainer(
   VectorSiteContainer* sites;
 
   if (AlphabetTools::isRNYAlphabet(alpha))
+  {
+    const SequenceTools ST;
+    sites = new VectorSiteContainer(alpha);
+    for (unsigned int i = 0; i < sites2->getNumberOfSequences(); i++)
     {
-      const SequenceTools ST;
-      sites = new VectorSiteContainer(alpha);
-      for (unsigned int i = 0; i < sites2->getNumberOfSequences(); i++)
-        {
-          sites->addSequence(*(ST.RNYslice(sites2->getSequence(i))));
-          }
-      delete sites2;
-      }
+      sites->addSequence(*(ST.RNYslice(sites2->getSequence(i))));
+    }
+    delete sites2;
+  }
   else
     sites = sites2;
 
-  if (verbose) ApplicationTools::displayResult("Sequence file " + suffix, sequenceFilePath);
-
   // Look for site selection:
-  if (format == "Mase")
+  if (iAln->getFormatName() == "MASE file")
   {
     // getting site set:
     string siteSet = ApplicationTools::getStringParameter("siteSelection", args, "none", suffix, suffixIsOptional, false);
@@ -468,18 +344,19 @@ VectorSiteContainer* SequenceApplicationTools::getSitesToAnalyse(
   string option = ApplicationTools::getStringParameter("input.sequence.sites_to_use", params, "complete", suffix, suffixIsOptional);
   if (verbose)
     ApplicationTools::displayResult("Sites to use", option);
-  sitesToAnalyse = new VectorSiteContainer(allSites);
   if (option == "all")
   {
+    sitesToAnalyse = new VectorSiteContainer(allSites);
     string maxGapOption = ApplicationTools::getStringParameter("input.sequence.max_gap_allowed", params, "100%", suffix, suffixIsOptional);
 
     if (maxGapOption[maxGapOption.size() - 1] == '%')
     {
       double gapFreq = TextTools::toDouble(maxGapOption.substr(0, maxGapOption.size() - 1)) / 100.;
-      if (gapFreq < 1) {
+      if (gapFreq < 1)
+      {
         if (verbose)
           ApplicationTools::displayTask("Remove sites with gaps", true);
-        for (unsigned int i = sitesToAnalyse->getNumberOfSites(); i > 0; i--)
+        for (size_t i = sitesToAnalyse->getNumberOfSites(); i > 0; --i)
         {
           if (verbose)
             ApplicationTools::displayGauge(sitesToAnalyse->getNumberOfSites() - i, sitesToAnalyse->getNumberOfSites() - 1, '=');
@@ -494,16 +371,16 @@ VectorSiteContainer* SequenceApplicationTools::getSitesToAnalyse(
     }
     else
     {
-      unsigned int gapNum = TextTools::to<unsigned int>(maxGapOption);
+      size_t gapNum = TextTools::to<size_t>(maxGapOption);
       if (gapNum < sitesToAnalyse->getNumberOfSequences())
       {
         if (verbose)
           ApplicationTools::displayTask("Remove sites with gaps", true);
-        for (unsigned int i = sitesToAnalyse->getNumberOfSites(); i > 0; i--)
+        for (size_t i = sitesToAnalyse->getNumberOfSites(); i > 0; i--)
         {
           if (verbose)
             ApplicationTools::displayGauge(sitesToAnalyse->getNumberOfSites() - i, sitesToAnalyse->getNumberOfSites() - 1, '=');
-          map<int, unsigned int> counts;
+          map<int, size_t> counts;
           SiteTools::getCounts(sitesToAnalyse->getSite(i - 1), counts);
           if (counts[-1] > gapNum)
             sitesToAnalyse->deleteSite(i - 1);
@@ -512,29 +389,86 @@ VectorSiteContainer* SequenceApplicationTools::getSitesToAnalyse(
           ApplicationTools::displayTaskDone();
       }
     }
+
+    string maxUnresolvedOption = ApplicationTools::getStringParameter("input.sequence.max_unresolved_allowed", params, "100%", suffix, suffixIsOptional);
+
+    size_t sAlph = sitesToAnalyse->getAlphabet()->getSize();
+
+    if (maxUnresolvedOption[maxUnresolvedOption.size() - 1] == '%')
+    {
+      double unresolvedFreq = TextTools::toDouble(maxUnresolvedOption.substr(0, maxUnresolvedOption.size() - 1)) / 100.;
+      if (unresolvedFreq < 1)
+      {
+        if (verbose)
+          ApplicationTools::displayTask("Remove unresolved sites", true);
+        for (size_t i = sitesToAnalyse->getNumberOfSites(); i > 0; --i)
+        {
+          if (verbose)
+            ApplicationTools::displayGauge(sitesToAnalyse->getNumberOfSites() - i, sitesToAnalyse->getNumberOfSites() - 1, '=');
+          map<int, double> freq;
+          SiteTools::getFrequencies(sitesToAnalyse->getSite(i - 1), freq);
+          double x = 0;
+          for (unsigned int l = 0; l < sAlph; l++)
+          {
+            x += freq[l];
+          }
+          if (1 - x > unresolvedFreq)
+            sitesToAnalyse->deleteSite(i - 1);
+        }
+        if (verbose)
+          ApplicationTools::displayTaskDone();
+      }
+    }
+    else
+    {
+      size_t nbSeq = sitesToAnalyse->getNumberOfSequences();
+      size_t unresolvedNum = TextTools::to<size_t>(maxUnresolvedOption);
+      if (unresolvedNum < nbSeq)
+      {
+        if (verbose)
+          ApplicationTools::displayTask("Remove sites with gaps", true);
+        for (size_t i = sitesToAnalyse->getNumberOfSites(); i > 0; i--)
+        {
+          if (verbose)
+            ApplicationTools::displayGauge(sitesToAnalyse->getNumberOfSites() - i, sitesToAnalyse->getNumberOfSites() - 1, '=');
+          map<int, size_t> counts;
+          SiteTools::getCounts(sitesToAnalyse->getSite(i - 1), counts);
+          size_t x = 0;
+          for (int l = 0; l < static_cast<int>(sAlph); l++)
+          {
+            x += counts[l];
+          }
+
+          if (nbSeq - x > unresolvedNum)
+            sitesToAnalyse->deleteSite(i - 1);
+        }
+        if (verbose)
+          ApplicationTools::displayTaskDone();
+      }
+    }
+
     if (gapAsUnknown)
     {
       SiteContainerTools::changeGapsToUnknownCharacters(*sitesToAnalyse);
-    }  
+    }
   }
   else if (option == "complete")
   {
     sitesToAnalyse = SiteContainerTools::getCompleteSites(allSites);
-    int nbSites = sitesToAnalyse->getNumberOfSites();
+    size_t nbSites = sitesToAnalyse->getNumberOfSites();
     if (verbose)
       ApplicationTools::displayResult("Complete sites", TextTools::toString(nbSites));
   }
   else if (option == "nogap")
   {
     sitesToAnalyse = SiteContainerTools::getSitesWithoutGaps(allSites);
-    int nbSites = sitesToAnalyse->getNumberOfSites();
+    size_t nbSites = sitesToAnalyse->getNumberOfSites();
     if (verbose)
       ApplicationTools::displayResult("Sites without gap", TextTools::toString(nbSites));
   }
   else
   {
-    ApplicationTools::displayError("Option '" + option + "' unknown in parameter 'sequence.sitestouse'.");
-    exit(-1);
+    throw Exception("Option '" + option + "' unknown in parameter 'sequence.sites_to_use'.");
   }
 
   if (AlphabetTools::isCodonAlphabet(sitesToAnalyse->getAlphabet()))
@@ -567,33 +501,16 @@ void SequenceApplicationTools::writeSequenceFile(
 {
   string sequenceFilePath = ApplicationTools::getAFilePath("output.sequence.file", params, true, false, suffix, false);
   string sequenceFormat   = ApplicationTools::getStringParameter("output.sequence.format", params, "Fasta", suffix, false, true);
-  string format = "";
-  map<string, string> args;
-  KeyvalTools::parseProcedure(sequenceFormat, format, args);
-  unsigned int ncol = ApplicationTools::getParameter<unsigned int>("length", args, 100, "", true, false);
-  auto_ptr<OSequence> oSeq;
-  if (format == "Fasta")
-  {
-    oSeq.reset(new Fasta(ncol));
-  }
-  else if (format == "Mase")
-  {
-    oSeq.reset(new Mase(ncol));
-  }
-  else
-  {
-    ApplicationTools::displayError("Format '" + format + "' unknown.");
-    exit(-1);
-  }
-
+  BppOSequenceWriterFormat bppoWriter(verbose);
+  auto_ptr<OSequence> oSeq(bppoWriter.read(sequenceFormat));
   if (verbose)
   {
-    ApplicationTools::displayResult("Output file format", format);
-    ApplicationTools::displayResult("Output file ", sequenceFilePath);
+    ApplicationTools::displayResult("Output sequence file " + suffix, sequenceFilePath);
+    ApplicationTools::displayResult("Output sequence format " + suffix, oSeq->getFormatName());
   }
 
   // Write sequences:
-  oSeq->write(sequenceFilePath, sequences, true);
+  oSeq->writeSequences(sequenceFilePath, sequences, true);
 }
 
 /******************************************************************************/
@@ -606,81 +523,17 @@ void SequenceApplicationTools::writeAlignmentFile(
 {
   string sequenceFilePath = ApplicationTools::getAFilePath("output.sequence.file", params, true, false, suffix, false);
   string sequenceFormat   = ApplicationTools::getStringParameter("output.sequence.format", params, "Fasta", suffix, false, true);
-  string format = "";
-  map<string, string> args;
-  KeyvalTools::parseProcedure(sequenceFormat, format, args);
-  unsigned int ncol = ApplicationTools::getParameter<unsigned int>("length", args, 100, "", true, false);
-  auto_ptr<OAlignment> oSeq;
-  if (format == "Fasta")
-  {
-    oSeq.reset(new Fasta(ncol));
-  }
-  else if (format == "Mase")
-  {
-    oSeq.reset(new Mase(ncol));
-  }
-  else if (format == "Phylip")
-  {
-    bool sequential = true, extended = true;
-    string split = "  ";
-    if (args.find("order") != args.end())
-    {
-      if (args["order"] == "sequential")
-        sequential = true;
-      else if (args["order"] == "interleaved")
-        sequential = false;
-      else
-        ApplicationTools::displayWarning("Argument '" +
-                                         args["order"] +
-                                         "' for argument 'Phylip#order' is unknown. " +
-                                         "Default used instead: sequential.");
-    }
-    else
-      ApplicationTools::displayWarning("Argument 'Phylip#order' not found. Default used instead: sequential.");
-    if (args.find("type") != args.end())
-    {
-      if (args["type"] == "extended")
-      {
-        extended = true;
-        split = ApplicationTools::getStringParameter("split", args, "spaces", "", true, false);
-        if (split == "spaces")
-          split = "  ";
-        else if (split == "tab")
-          split = "\t";
-        else
-          throw Exception("Unknown option for Phylip#split: " + split);
-      }
-      else if (args["type"] == "classic")
-        extended = false;
-      else
-        ApplicationTools::displayWarning("Argument '" +
-                                         args["type"] + "' for parameter 'Phylip#type' is unknown. " +
-                                         "Default used instead: extended.");
-    }
-    else
-      ApplicationTools::displayWarning("Argument 'Phylip#type' not found. Default used instead: extended.");
-    oSeq.reset(new Phylip(extended, sequential, ncol, true, split));
-  }
-  else if (format == "Stockholm")
-  {
-    oSeq.reset(reinterpret_cast<OAlignment*>(new Stockholm()));
-  }
-  else
-  {
-    ApplicationTools::displayError("Format '" + format + "' unknown.");
-    exit(-1);
-  }
-
+  BppOAlignmentWriterFormat bppoWriter(verbose);
+  auto_ptr<OAlignment> oAln(bppoWriter.read(sequenceFormat));
   if (verbose)
   {
-    ApplicationTools::displayResult("Output file format", format);
-    ApplicationTools::displayResult("Output file ", sequenceFilePath);
+    ApplicationTools::displayResult("Output alignment file " + suffix, sequenceFilePath);
+    ApplicationTools::displayResult("Output alignment format " + suffix, oAln->getFormatName());
   }
 
   // Write sequences:
-  oSeq->write(sequenceFilePath, sequences, true);
+  oAln->writeAlignment(sequenceFilePath, sequences, true);
 }
 
-
 /******************************************************************************/
 
