@@ -6,7 +6,7 @@
 //
 
 /*
-Copyright or © or Copr. CNRS, (November 17, 2004)
+Copyright or © or Copr. Bio++ Development Team, (November 17, 2004)
 
 This software is a computer program whose purpose is to provide classes
 for sequences analysis.
@@ -45,6 +45,7 @@ knowledge of the CeCILL license and that you accept its terms.
 #include <string>
 #include <vector>
 #include <map>
+#include <memory>
 
 #include "SequenceContainer.h"
 #include "OrderedSequenceContainer.h"
@@ -52,7 +53,7 @@ knowledge of the CeCILL license and that you accept its terms.
 namespace bpp
 {
 
-typedef std::vector<unsigned int> SequenceSelection;
+typedef std::vector<size_t> SequenceSelection;
 
 /**
  * @brief Utilitary methods dealing with sequence containers.
@@ -76,7 +77,7 @@ class SequenceContainerTools
      * @param size     The number of sequences in the container.
      * @return A pointer toward a newly created container.
      */
-    static SequenceContainer* createContainerOfSpecifiedSize(const Alphabet* alphabet, unsigned int size);
+    static SequenceContainer* createContainerOfSpecifiedSize(const Alphabet* alphabet, size_t size);
 
     /**
      * @brief Create a container with specified names.
@@ -94,12 +95,32 @@ class SequenceContainerTools
       const Alphabet* alphabet,
       const std::vector<std::string>& seqNames)
       throw (Exception);
-      
+ 
+    /**
+     * @brief Generic function which creates a new container from another one,
+     * by specifying the class of sequence to be stored.
+     *
+     * Compared to several copy constructors, this function allows to change the class of
+     * the inner sequence class used for storing sequences.
+     * The function used the addSequence method, so that it can also be used to
+     * concatenate containers.
+     *
+     * @param input The container to copy.
+     * @param output The container where new sequences will be appended.
+     */
+    template<class ContFrom, class ContTo, class Seq>
+    static void convertContainer(const ContFrom& input, ContTo& output) {
+      for (size_t i = 0; i < input.getNumberOfSequences(); ++i) {
+        std::auto_ptr<Seq> seq(new Seq(input.getSequence(i)));
+        output.addSequence(*seq);
+      }
+    }
+
     /**
      * @brief Add a specified set of sequences from a container to another.
      *
      * Sequences are specified by their position, beginning at 0.
-     * Name verification will be performed, only if the output contianer is not empty,
+     * Name verification will be performed, only if the output container is not empty,
      * based on the assumption that the container passed as argument is a correct one.
      * Redundant selection is not checked, so be careful with what you're doing!
      *
@@ -116,18 +137,20 @@ class SequenceContainerTools
      * @brief Add a specified set of sequences from a container to another.
      *
      * Sequences are specified by their names.
-     * Name verification will be performed, only if the output contianer is not empty,
+     * Name verification will be performed, only if the output container is not empty,
      * based on the assumption that the container passed as argument is a correct one.
      * Redundant selection is not checked, so be careful with what you're doing!
      *
      * @author Julien Dutheil
      *
      * @param sequences The container from wich sequences are to be taken.
-     * @param selection The positions of all sequences to retrieve.
+     * @param selection The names of all sequences to retrieve.
      * @param outputCont A container where the selection should be added.
+     * @param strict If yes, trying to select a sequence that is not present
+     * will raise an exception. If no, only available sequence will be added.
      * @throw Exception In case of bad sequence name, alphabet mismatch, etc.
      */
-    static void getSelectedSequences(const SequenceContainer& sequences, const std::vector<std::string>& selection, SequenceContainer& outputCont) throw (Exception);
+    static void getSelectedSequences(const SequenceContainer& sequences, const std::vector<std::string>& selection, SequenceContainer& outputCont, bool strict = true) throw (Exception);
 
     /**
      * @brief Remove all sequences that are not in a given selection from a given container.
@@ -179,7 +202,7 @@ class SequenceContainerTools
    * States are stored as their int code.
    */
   
-  static void  getFrequencies(const SequenceContainer& sequences, std::map<int, double>& f, unsigned int pseudoCount = 0);
+  static void  getFrequencies(const SequenceContainer& sequences, std::map<int, double>& f, double pseudoCount = 0);
   
     /**
      * @brief Append all the sequences of a SequenceContainer to the end of another.
@@ -192,7 +215,7 @@ class SequenceContainerTools
     throw (Exception)
     {
       std::vector<std::string> seqNames = seqCont2.getSequencesNames();
-      for (unsigned int i = 0; i < seqNames.size(); i++)
+      for (size_t i = 0; i < seqNames.size(); i++)
         seqCont1.addSequence(seqCont2.getSequence(seqNames[i]), checkNames);
     }
     /**
@@ -205,7 +228,7 @@ class SequenceContainerTools
     static void append(SequenceContainer& seqCont1, const OrderedSequenceContainer& seqCont2, bool checkNames=true)
     throw (Exception)
     {
-      for (unsigned int i = 0; i < seqCont2.getNumberOfSequences(); i++)
+      for (size_t i = 0; i < seqCont2.getNumberOfSequences(); i++)
         seqCont1.addSequence(seqCont2.getSequence(i), checkNames);
     }
     
@@ -230,7 +253,7 @@ class SequenceContainerTools
         throw AlphabetMismatchException("SequenceContainerTools::merge.", seqCont1.getAlphabet(), seqCont2.getAlphabet());
 
       std::vector<std::string> seqNames = seqCont1.getSequencesNames();
-      for (unsigned int i = 0; i < seqNames.size(); i++)
+      for (size_t i = 0; i < seqNames.size(); i++)
       {
         BasicSequence tmp = seqCont1.getSequence(seqNames[i]);
         tmp.append(seqCont2.getContent(seqNames[i]));
@@ -251,7 +274,7 @@ class SequenceContainerTools
     {  
       std::vector<std::string> seqNames = seqCont.getSequencesNames();
       bool checkNames = outputCont.getNumberOfSequences() > 0;
-      for (unsigned int i = 0; i < seqNames.size(); i++)
+      for (size_t i = 0; i < seqNames.size(); i++)
       {
         BasicSequence seq(seqNames[i], seqCont.toString(seqNames[i]), outputCont.getAlphabet());
         outputCont.addSequence(seq, checkNames);
@@ -266,7 +289,7 @@ class SequenceContainerTools
      * @return          A SequenceContainer with a nucleotide alphabet.
      * @throw AlphabetException If input sequences are not registered with a codon alphabet.
      */
-    static SequenceContainer* getCodonPosition(const SequenceContainer& sequences, unsigned int pos) throw (AlphabetException);
+    static SequenceContainer* getCodonPosition(const SequenceContainer& sequences, size_t pos) throw (AlphabetException);
 
 };
 
