@@ -43,7 +43,7 @@
 #include "SiteContainer.h"
 #include "VectorSiteContainer.h"
 #include "AlignedSequenceContainer.h"
-#include "../StateProperties/AlphabetIndex2.h"
+#include "../AlphabetIndex/AlphabetIndex2.h"
 #include "../DistanceMatrix.h"
 #include <Bpp/Numeric/Matrix/Matrix.h>
 
@@ -54,7 +54,7 @@
 namespace bpp
 {
 
-typedef std::vector<unsigned int> SiteSelection;
+typedef std::vector<size_t> SiteSelection;
 
 /**
  * @brief Some utililitary methods to deal with site containers.
@@ -119,19 +119,43 @@ class SiteContainerTools
 		 * @return A pointer toward a new SiteContainer.
 		 */
 		static SiteContainer* removeGapOrUnresolvedOnlySites(const SiteContainer& sites);
+		
+    /**
+		 * @brief Remove gap/unresolved-only sites from a site set.
+		 *
+		 * @param sites The container where the sites have to be removed.
+		 */
+    static void removeGapOrUnresolvedOnlySites(SiteContainer& sites);
 
-               /**
-                * @brief Get a site set without stop codons, if the alphabet is a CodonAlphabet, otherwise throws an Exception.
-                *
-                * This function build a new SiteContainer instance without sites that have at least a stop codon.
-                * The container passed as input is not modified, all sites are copied.
-                *
-                * @param sites The container to analyse.
-                * @return A pointer toward a new SiteContainer.
-                */
-               static SiteContainer* removeStopCodonSites(const SiteContainer& sites) throw (AlphabetException);
+    /**
+		 * @brief Get a siteset with sites with less than a given amount of gaps.
+		 *
+		 * @param sites The container from which the sites have to be removed.
+     * @param maxFreqGaps The maximum frequency of gaps in each site.
+		 * @return A pointer toward a new SiteContainer.
+		 */
+     static SiteContainer* removeGapSites(const SiteContainer& sites, double maxFreqGaps);
 
-                /**
+    /**
+		 * @brief Remove sites with a given amount of gaps.
+		 *
+		 * @param sites The container from which the sites have to be removed.
+     * @param maxFreqGaps The maximum frequency of gaps in each site.
+		 */
+     static void removeGapSites(SiteContainer& sites, double maxFreqGaps);
+
+    /**
+     * @brief Get a site set without stop codons, if the alphabet is a CodonAlphabet, otherwise throws an Exception.
+     *
+     * This function build a new SiteContainer instance without sites that have at least a stop codon.
+     * The container passed as input is not modified, all sites are copied.
+     *
+     * @param sites The container to analyse.
+     * @return A pointer toward a new SiteContainer.
+     */
+    static SiteContainer* removeStopCodonSites(const SiteContainer& sites) throw (AlphabetException);
+
+    /**
 		 * @brief Create a new container with a specified set of sites.
 		 *
 		 * A new VectorSiteContainer is created with specified sites.
@@ -225,7 +249,7 @@ class SiteContainerTools
      * @param seq The sequence to translate.
      * @return A map with original sequence positions as keys, and translated positions as values.
      */
-    static std::map<unsigned int, unsigned int> getSequencePositions(const Sequence& seq);
+    static std::map<size_t, size_t> getSequencePositions(const Sequence& seq);
 
     /**
      * @brief Get the index of each alignment position in an aligned sequence.
@@ -236,7 +260,7 @@ class SiteContainerTools
      * @param seq The sequence to translate.
      * @return A map with original alignement positions as keys, and translated positions as values.
      */
-    static std::map<unsigned int, unsigned int> getAlignmentPositions(const Sequence& seq);
+    static std::map<size_t, size_t> getAlignmentPositions(const Sequence& seq);
 
     /**
      * @brief Fill a numeric matrix with the size of the alignment, containing the each sequence position.
@@ -247,7 +271,7 @@ class SiteContainerTools
      * @param positions A matrix object which is going to be resized and filled with the corresponding positions.
      * @author Julien Dutheil
      */
-    static void getSequencePositions(const SiteContainer& sites, Matrix<unsigned int>& positions);
+    static void getSequencePositions(const SiteContainer& sites, Matrix<size_t>& positions);
     /** @} */
 
     /**
@@ -263,7 +287,7 @@ class SiteContainerTools
      * @throw AlphabetMismatchException If the sequences do not share the same alphabet.
      * @throw Exception If the sequence do not match.
      */
-    static std::map<unsigned int, unsigned int> translateAlignment(const Sequence& seq1, const Sequence& seq2) throw (AlphabetMismatchException, Exception);
+    static std::map<size_t, size_t> translateAlignment(const Sequence& seq1, const Sequence& seq2) throw (AlphabetMismatchException, Exception);
 
     /**
      * @brief Translate sequence positions from a sequence to another in the same alignment.
@@ -276,7 +300,7 @@ class SiteContainerTools
      * @param i2 The index of the reference sequence.
      * @return A map with original sequence positions as keys, and translated positions as values.
      */
-    static std::map<unsigned int, unsigned int> translateSequence(const SiteContainer& sequences, unsigned int i1, unsigned int i2);
+    static std::map<size_t, size_t> translateSequence(const SiteContainer& sequences, size_t i1, size_t i2);
 
     /**
      * @brief Align two sequences using the Needleman-Wunsch dynamic algorithm.
@@ -292,7 +316,7 @@ class SiteContainerTools
      * @return A new SiteContainer instance.
      * @throw AlphabetMismatchException If the sequences and the score matrix do not share the same alphabet.
      */
-    static AlignedSequenceContainer* alignNW(const Sequence& seq1, const Sequence& seq2, const AlphabetIndex2<double>& s, double gap) throw (AlphabetMismatchException);
+    static AlignedSequenceContainer* alignNW(const Sequence& seq1, const Sequence& seq2, const AlphabetIndex2& s, double gap) throw (AlphabetMismatchException);
 
     /**
      * @brief Align two sequences using the Needleman-Wunsch dynamic algorithm.
@@ -309,7 +333,7 @@ class SiteContainerTools
      * @return A new SiteContainer instance.
      * @throw AlphabetMismatchException If the sequences and the score matrix do not share the same alphabet.
      */
-    static AlignedSequenceContainer* alignNW(const Sequence& seq1, const Sequence& seq2, const AlphabetIndex2<double>& s, double opening, double extending) throw (AlphabetMismatchException);
+    static AlignedSequenceContainer* alignNW(const Sequence& seq1, const Sequence& seq2, const AlphabetIndex2& s, double opening, double extending) throw (AlphabetMismatchException);
 
     /**
      * @brief Sample sites in an alignment.
@@ -324,7 +348,7 @@ class SiteContainerTools
      * @param index [out] If non-null the underlying vector will be appended with the original site indices.
      * @return A sampled alignment with nbSites sites taken from the input one.
      */
-    static VectorSiteContainer* sampleSites(const SiteContainer& sites, unsigned int nbSites, std::vector<unsigned int>* index = 0);
+    static VectorSiteContainer* sampleSites(const SiteContainer& sites, size_t nbSites, std::vector<size_t>* index = 0);
 
     /**
      * @brief Bootstrap sites in an alignment.
@@ -384,7 +408,7 @@ class SiteContainerTools
      * If set to yes, the gap option will also apply to unresolved characters.
      * @return All pairwise similarity measures.
      */
-    static DistanceMatrix* computeSimilarityMatrix(const SiteContainer& sites, bool dist = false, const std::string & gapOption = SIMILARITY_NOFULLGAP, bool unresolvedAsGap = true);
+    static DistanceMatrix* computeSimilarityMatrix(const SiteContainer& sites, bool dist = false, const std::string& gapOption = SIMILARITY_NOFULLGAP, bool unresolvedAsGap = true);
 
     static const std::string SIMILARITY_ALL;
     static const std::string SIMILARITY_NOFULLGAP;
@@ -419,14 +443,14 @@ class SiteContainerTools
      * Calculations are made according to formula for the "CS" score in Thompson et al 1999, Nucleic Acids Research (1999):27(13);2682–2690.
      *
      * @param positions1 Alignment index for the test alignment.
-     * @param positions1 Alignment index for the reference alignment.
+     * @param positions2 Alignment index for the reference alignment.
      * @param na         The score to use if the tested column is full of gap.
      * @return A vector of score, as 0 or 1.
      * @see getSequencePositions for creating the alignment indexes.
      * @warning The indexes for the two alignments must have the sequences in the exact same order!
      * @author Julien Dutheil
      */
-    static std::vector<int> getColumnScores(const Matrix<unsigned int>& positions1, const Matrix<unsigned int>& positions2, int na = 0);
+    static std::vector<int> getColumnScores(const Matrix<size_t>& positions1, const Matrix<size_t>& positions2, int na = 0);
    
     /**
      * @brief Compare an alignment to a reference alignment, and compute the sum-of-pairs scores.
@@ -434,14 +458,14 @@ class SiteContainerTools
      * Calculations are made according to formula for the "SPS" score in Thompson et al 1999, Nucleic Acids Research (1999):27(13);2682–2690.
      *
      * @param positions1 Alignment index for the test alignment.
-     * @param positions1 Alignment index for the reference alignment.
+     * @param positions2 Alignment index for the reference alignment.
      * @param na         The score to use if the tested column is not testable, that is not containing at least to residues.
      * @return A vector of score, between 0 and 1 (+ na value).
      * @see getSequencePositions for creating the alignment indexes.
      * @warning The indexes for the two alignments must have the sequences in the exact same order!
      * @author Julien Dutheil
      */
-    static std::vector<double> getSumOfPairsScores(const Matrix<unsigned int>& positions1, const Matrix<unsigned int>& positions2, double na = 0);
+    static std::vector<double> getSumOfPairsScores(const Matrix<size_t>& positions1, const Matrix<size_t>& positions2, double na = 0);
 };
 
 } //end of namespace bpp.
