@@ -79,11 +79,47 @@ class AbstractISequence:
      * @param sc     The sequence container to update.
      * @throw Exception If the file is not in the specified format.
      */
-    virtual void read(std::istream& input, SequenceContainer& sc) const throw (Exception)
+   virtual void readSequences(std::istream& input, SequenceContainer& sc) const throw (Exception)
     {
-      appendFromStream(input, sc);
+      appendSequencesFromStream(input, sc);
     }
-    
+ 
+   /**
+     * @brief Add sequences to a container from a file.
+     *
+     * @param path  The path to the file to read.
+     * @param sc    The sequence container to update.
+     * @throw Exception If the file is not in the specified format.
+     */
+    virtual void readSequences(const std::string& path, SequenceContainer& sc) const throw (Exception)
+    {
+      appendSequencesFromFile(path, sc);
+    }
+ 
+    virtual
+#if defined(NO_VIRTUAL_COV)
+    SequenceContainer*
+#else
+    VectorSequenceContainer*
+#endif
+    readSequences(std::istream& input, const Alphabet* alpha) const throw (Exception)
+    {
+      return readSequencesFromStream(input, alpha);
+    }
+
+    virtual
+#if defined(NO_VIRTUAL_COV)
+    SequenceContainer*
+#else
+    VectorSequenceContainer*
+#endif
+    readSequences(const std::string& path , const Alphabet* alpha) const throw (Exception)
+    {
+      return readSequencesFromFile(path, alpha);
+    }
+    /** @} */
+ 
+   
   protected:
     /**
      * @brief Append sequences to a container from a stream.
@@ -94,22 +130,8 @@ class AbstractISequence:
      * @param sc     The sequence container to update.
      * @throw Exception If the file is not in the specified format.
      */
-    virtual void appendFromStream(std::istream& input, SequenceContainer& sc) const throw (Exception) = 0;
+    virtual void appendSequencesFromStream(std::istream& input, SequenceContainer& sc) const throw (Exception) = 0;
   
-  public:
-    /**
-     * @brief Add sequences to a container from a file.
-     *
-     * @param path  The path to the file to read.
-     * @param sc    The sequence container to update.
-     * @throw Exception If the file is not in the specified format.
-     */
-    virtual void read(const std::string& path, SequenceContainer& sc) const throw (Exception)
-    {
-      appendFromFile(path, sc);
-    }
-    
-  protected:
     /**
      * @brief Append sequences to a container from a file.
      *
@@ -117,26 +139,13 @@ class AbstractISequence:
      * @param sc    The sequence container to update.
      * @throw Exception If the file is not in the specified format.
      */
-    virtual void appendFromFile(const std::string& path, SequenceContainer& sc) const throw (Exception)
+    virtual void appendSequencesFromFile(const std::string& path, SequenceContainer& sc) const throw (Exception)
     {
       std::ifstream input(path.c_str(), std::ios::in);
-      read(input, sc);
+      appendSequencesFromStream(input, sc);
       input.close();
     }
 
-  public:
-    virtual
-#if defined(NO_VIRTUAL_COV)
-    SequenceContainer*
-#else
-    VectorSequenceContainer*
-#endif
-    read(std::istream& input, const Alphabet* alpha) const throw (Exception)
-    {
-      return readFromStream(input, alpha);
-    }
-
-  protected:
     /**
      * @brief Read sequences from a stream.
      * 
@@ -145,34 +154,13 @@ class AbstractISequence:
      * @return A sequence container.
      * @throw Exception If the file is not in the specified format.
      */
-    virtual
-#if defined(NO_VIRTUAL_COV)
-    SequenceContainer*
-#else
-    VectorSequenceContainer*
-#endif
-    readFromStream(std::istream& input, const Alphabet* alpha) const throw (Exception)
+    virtual VectorSequenceContainer* readSequencesFromStream(std::istream& input, const Alphabet* alpha) const throw (Exception)
     {
       VectorSequenceContainer* vsc = new VectorSequenceContainer(alpha);
-      appendFromStream(input, *vsc);
+      appendSequencesFromStream(input, *vsc);
       return vsc;
     }
 
-  public:
-    virtual
-#if defined(NO_VIRTUAL_COV)
-    SequenceContainer*
-#else
-    VectorSequenceContainer*
-#endif
-    read(const std::string& path , const Alphabet* alpha) const throw (Exception)
-    {
-      VectorSequenceContainer* vsc = new VectorSequenceContainer(alpha);
-      read(path, *vsc);
-      return vsc;
-    }
-  
-  protected:
     /**
      * @brief Append sequences to a container from a file.
      *
@@ -180,19 +168,12 @@ class AbstractISequence:
      * @param alpha The alphabet to use.
      * @throw Exception If the file is not in the specified format.
      */
-    virtual
-#if defined(NO_VIRTUAL_COV)
-    SequenceContainer*
-#else
-    VectorSequenceContainer*
-#endif
-    readFromFile(const std::string& path , const Alphabet* alpha) const throw (Exception)
+    virtual VectorSequenceContainer* readSequencesFromFile(const std::string& path , const Alphabet* alpha) const throw (Exception)
     {
       VectorSequenceContainer* vsc = new VectorSequenceContainer(alpha);
-      appendFromFile(path, *vsc);
+      appendSequencesFromFile(path, *vsc);
       return vsc;
     }
-    /** @} */
 };
 
 } //end of namespace bpp.
