@@ -70,12 +70,12 @@ class AbstractOSequence:
 		 *
 		 * @{
 		 */ 
-		void write(std::ostream& output, const SequenceContainer& sc) const throw (Exception) = 0;
-		void write(const std::string& path, const SequenceContainer& sc, bool overwrite=true) const throw (Exception)
+		void writeSequences(std::ostream& output, const SequenceContainer& sc) const throw (Exception) = 0;
+		void writeSequences(const std::string& path, const SequenceContainer& sc, bool overwrite=true) const throw (Exception)
 		{
 			// Open file in specified mode
       std::ofstream output(path.c_str(), overwrite ? (std::ios::out) : (std::ios::out | std::ios::app));
-			write(output, sc);
+			writeSequences(output, sc);
 			output.close();
 		}
 		/** @} */
@@ -83,49 +83,24 @@ class AbstractOSequence:
     /**
 		 * @name OAlignment methods:
 		 *
+     * As a SiteContainer is a specialization of SequenceContainer, it is assumed that a OSequence
+     * object can write aligned sequence just like a OAlignment object.
+     * Therefore it implements the OAlignment interface by down-casting the SiteContainer
+     * to a SequenceContainer. 
 		 * @{
 		 */ 
-		void write(std::ostream& output, const SiteContainer& sc) const throw (Exception)
+		void writeAlignment(std::ostream& output, const SiteContainer& sc) const throw (Exception)
     {
-      write(output, dynamic_cast<const SequenceContainer&>(sc));
+      writeSequences(output, dynamic_cast<const SequenceContainer&>(sc));
     }
-		void write(const std::string& path, const SiteContainer& sc, bool overwrite=true) const throw (Exception)
+		void writeAlignment(const std::string& path, const SiteContainer& sc, bool overwrite=true) const throw (Exception)
 		{
-      write(path, dynamic_cast<const SequenceContainer&>(sc), overwrite);
+      writeSequences(path, dynamic_cast<const SequenceContainer&>(sc), overwrite);
 		}
 		/** @} */
 
 };
 
-/**
- * @brief Partial implementation of the OAlignment interface.
- */
-class AbstractOAlignment:
-  public virtual OAlignment
-{
-
-	public: 
-		AbstractOAlignment() {}
-		virtual ~AbstractOAlignment() {}
-
-	public:
-
-		/**
-		 * @name OAlignment methods:
-		 *
-		 * @{
-		 */ 
-		void write(std::ostream& output, const SiteContainer& sc) const throw (Exception) = 0;
-		void write(const std::string& path, const SiteContainer& sc, bool overwrite = true) const throw (Exception)
-		{
-			// Open file in specified mode
-      std::ofstream output(path.c_str(), overwrite ? (std::ios::out) : (std::ios::out | std::ios::app));
-			write(output, sc);
-			output.close();
-		}
-		/** @} */
-};
-
 } //end of namespace bpp.
 
 #endif //_ABSTRACTOSEQUENCE_H_
