@@ -57,17 +57,14 @@ bool Fasta::nextSequence(istream& input, Sequence& seq) const throw (Exception)
   if (!input)
     throw IOException("Fasta::nextSequence: can't read from istream input");
   string seqname = "";
+  string content = "";
   Comments seqcmts;
-  seq.setContent("");
-  char c;
   short seqcpt = 0;
   string linebuffer = "";
-  string bufferleft = "";
-  vector<string> splitline;
-  unsigned int wordsize = seq.getAlphabet()->getStateCodingSize();
+  char c;
   while (!input.eof())
   {
-    c = input.peek();
+    c = static_cast<char>(input.peek());
     if (input.eof())
       c = '\n';
 
@@ -86,36 +83,7 @@ bool Fasta::nextSequence(istream& input, Sequence& seq) const throw (Exception)
     }
     if (c != '>' && !TextTools::isWhiteSpaceCharacter(c)) {
       // Sequence content
-      if (wordsize == 1)
-      {
-        for (unsigned int i = 0 ; i < linebuffer.size() ; i++)
-        {
-          if (! TextTools::isWhiteSpaceCharacter(linebuffer[i]))
-            seq.addElement(string(1, toupper(linebuffer[i])));
-        }
-      }
-      else
-      {
-        // Remove white spaces
-        linebuffer = TextTools::removeWhiteSpaces(linebuffer);
-        
-        if (!bufferleft.empty()) {
-          linebuffer = bufferleft + linebuffer;
-          bufferleft.clear();
-        }
-        splitline = TextTools::split(linebuffer, wordsize);
-        for (unsigned int j = 0 ; j < splitline.size() ; j++)
-        {
-          if (splitline[j].size() == wordsize)
-          {
-            seq.addElement(splitline[j]);
-          }
-          else
-          {
-            bufferleft += splitline[j];
-          }
-        }
-      }
+      content += TextTools::toUpper(TextTools::removeWhiteSpaces(linebuffer));
     }
   }
 
@@ -133,10 +101,13 @@ bool Fasta::nextSequence(istream& input, Sequence& seq) const throw (Exception)
       while (st.hasMoreToken()) {
         seqcmts.push_back(st.nextToken());
       }
+    } else {
+      seqcmts.push_back(seqcmt);
     }
     seq.setComments(seqcmts);
   }
   seq.setName(seqname);
+  seq.setContent(content);
   return res;
 }
 
@@ -172,7 +143,7 @@ void Fasta::writeSequence(ostream& output, const Sequence& seq) const throw (Exc
 
 /******************************************************************************/
 
-void Fasta::appendFromStream(istream& input, SequenceContainer& vsc) const throw (Exception)
+void Fasta::appendSequencesFromStream(istream& input, SequenceContainer& vsc) const throw (Exception)
 {
   if (!input)
     throw IOException("Fasta::appendFromStream: can't read from istream input");
@@ -229,7 +200,7 @@ void Fasta::appendFromStream(istream& input, SequenceContainer& vsc) const throw
 
 /******************************************************************************/
 
-void Fasta::write(ostream& output, const SequenceContainer& sc) const throw (Exception)
+void Fasta::writeSequences(ostream& output, const SequenceContainer& sc) const throw (Exception)
 {
 	if (!output)
     throw IOException("Fasta::write: can't write to ostream output");
@@ -264,10 +235,10 @@ void Fasta::FileIndex::build(const std::string& path) throw (Exception) {
   fileSize_ = f_in.tellg();
   // feed the map
   f_in.seekg(0, std::ios::beg);
-  int pos = f_in.tellg();
+  streampos pos = f_in.tellg();
   char ch;
   std::string seq_id = "";
-  while(f_in.get(ch)) {
+  while (f_in.get(ch)) {
     if (ch == '>') {
       pos = static_cast<int>(f_in.tellg()) - 1;
       std::getline(f_in, seq_id);
@@ -277,8 +248,8 @@ void Fasta::FileIndex::build(const std::string& path) throw (Exception) {
   f_in.close();
 }
 
-int Fasta::FileIndex::getSequencePosition(const std::string& id) const throw (Exception) {
-  std::map<std::string, int>::const_iterator it = index_.find(id);
+streampos Fasta::FileIndex::getSequencePosition(const std::string& id) const throw (Exception) {
+  std::map<std::string, streampos>::const_iterator it = index_.find(id);
   if (it != index_.end()) {
     return it->second;
   }
@@ -301,7 +272,7 @@ void Fasta::FileIndex::read(const std::string& path) throw (Exception) {
 
 void Fasta::FileIndex::write(const std::string& path) throw (Exception) {
   std::ofstream f_out(path.c_str());
-  for (std::map<std::string, int>::const_iterator it = index_.begin() ; it != index_.end() ; ++it) {
+  for (std::map<std::string, streampos>::const_iterator it = index_.begin() ; it != index_.end() ; ++it) {
     f_out << it->first << "\t" << bpp::TextTools::toString(it->second) << std::endl;
   }
   f_out.close();
@@ -309,7 +280,7 @@ void Fasta::FileIndex::write(const std::string& path) throw (Exception) {
 
 void Fasta::FileIndex::getSequence(const std::string& seqid, Sequence& seq, const std::string& path) const {
   Fasta fs(60);
-  int seq_pos = this->getSequencePosition(seqid);
+  streampos seq_pos = this->getSequencePosition(seqid);
   std::ifstream fasta(path.c_str());
   fasta.seekg(seq_pos);
   fs.nextSequence(fasta, seq);
