@@ -43,6 +43,7 @@ knowledge of the CeCILL license and that you accept its terms.
 #define _BPP_SEQ_IO_FASTA_H_
 
 #include "AbstractISequence.h"
+#include "AbstractIAlignment.h"
 #include "AbstractOSequence.h"
 #include "../Sequence.h"
 #include "../Container/SequenceContainer.h"
@@ -61,6 +62,7 @@ namespace bpp
  */
 class Fasta:
   public AbstractISequence,
+  public AbstractIAlignment,
   public AbstractOSequence,
   public virtual ISequenceStream,
   public virtual OSequenceStream
@@ -97,11 +99,17 @@ class Fasta:
      *
      * @{
      */
+    void appendSequencesFromStream(std::istream& input, SequenceContainer& sc) const throw (Exception);
+    /** @} */
+
     /**
-     * @copydoc AbstractISequence::appendFromStream(std::istream& input, SequenceContainer& sc) const
-     * @author Sylvain Gaillard
+     * @name The AbstractIAlignment interface.
+     *
+     * @{
      */
-    void appendFromStream(std::istream& input, SequenceContainer& sc) const throw (Exception);
+    void appendAlignmentFromStream(std::istream& input, SiteContainer& sc) const throw (Exception) {
+      appendSequencesFromStream(input, sc); //This may raise an exception if sequences are not aligned!
+    }
     /** @} */
 
     /**
@@ -109,14 +117,11 @@ class Fasta:
      *
      * @{
      */
-    /**
-     * @copydoc OSequence::write(std::ostream& output, const SequenceContainer& sc) const
-     * @author Sylvain Gaillard
-     */
-    void write(std::ostream & output, const SequenceContainer & sc) const throw (Exception);
-    void write(const std::string & path, const SequenceContainer & sc, bool overwrite=true) const throw (Exception)
+    void writeSequences(std::ostream& output, const SequenceContainer& sc) const throw (Exception);
+    
+    void writeSequences(const std::string& path, const SequenceContainer& sc, bool overwrite=true) const throw (Exception)
     {
-      AbstractOSequence::write(path, sc, overwrite);
+      AbstractOSequence::writeSequences(path, sc, overwrite);
     }
     /** @} */
   
@@ -137,10 +142,6 @@ class Fasta:
      *
      * @{
      */
-    /**
-     * @copydoc ISequenceStream::nextSequence(std::istream& input, Sequence& seq) const
-     * @author Sylvain Gaillard
-     */
     bool nextSequence(std::istream& input, Sequence& seq) const throw (Exception);
     /** @} */
 
@@ -149,10 +150,6 @@ class Fasta:
      *
      * @{
      */
-    /**
-     * @copydoc OSequenceStream::writeSequence(std::ostream& output, const Sequence& seq) const
-     * @author Sylvain Gaillard
-     */
     void writeSequence(std::ostream& output, const Sequence& seq) const throw (Exception);
     /** @} */
 
@@ -189,8 +186,8 @@ class Fasta:
         FileIndex(): index_(), fileSize_(0) {}
         ~FileIndex() {}
         void build(const std::string& path) throw (Exception);
-        int getSequencePosition(const std::string& id) const throw (Exception);
-        unsigned int getNumberOfSequences() const throw (Exception) {
+        std::streampos getSequencePosition(const std::string& id) const throw (Exception);
+        size_t getNumberOfSequences() const throw (Exception) {
           return index_.size();
         }
         /**
@@ -206,8 +203,8 @@ class Fasta:
          */
         void getSequence(const std::string& seqid, Sequence& seq, const std::string& path) const;
       private:
-        std::map<std::string, int> index_;
-        int fileSize_;
+        std::map<std::string, std::streampos> index_;
+        std::streampos fileSize_;
     };
 };
 
