@@ -5,7 +5,7 @@
 //
 
 /*
-Copyright or © or Copr. CNRS, (November 17, 2004)
+Copyright or © or Copr. Bio++ Development Team, (November 17, 2004)
 
 This software is a computer program whose purpose is to provide classes
 for sequences analysis.
@@ -38,25 +38,33 @@ knowledge of the CeCILL license and that you accept its terms.
 */
 
 #include "IoSequenceFactory.h"
+#include "Fasta.h"
+#include "Mase.h"
+#include "Clustal.h"
+#include "Dcse.h"
+#include "Phylip.h"
+#include "GenBank.h"
+#include "NexusIoSequence.h"
 
 using namespace bpp;
 using namespace std;
 
-const string IOSequenceFactory::FASTA_FORMAT              = "Fasta";
-const string IOSequenceFactory::MASE_FORMAT               = "Mase";  
-const string IOSequenceFactory::CLUSTAL_FORMAT            = "Clustal";
-const string IOSequenceFactory::DCSE_FORMAT               = "DCSE";  
-const string IOSequenceFactory::PHYLIP_FORMAT_INTERLEAVED = "Phylip I";  
-const string IOSequenceFactory::PHYLIP_FORMAT_SEQUENTIAL  = "Phylip S";  
-const string IOSequenceFactory::PAML_FORMAT_INTERLEAVED   = "PAML I";  
-const string IOSequenceFactory::PAML_FORMAT_SEQUENTIAL    = "PAML S";  
-const string IOSequenceFactory::GENBANK_FORMAT            = "GenBank";  
-const string IOSequenceFactory::NEXUS_FORMAT              = "Nexus";  
+const string IoSequenceFactory::FASTA_FORMAT              = "Fasta";
+const string IoSequenceFactory::MASE_FORMAT               = "Mase";  
+const string IoSequenceFactory::CLUSTAL_FORMAT            = "Clustal";
+const string IoSequenceFactory::DCSE_FORMAT               = "DCSE";  
+const string IoSequenceFactory::PHYLIP_FORMAT_INTERLEAVED = "Phylip I";  
+const string IoSequenceFactory::PHYLIP_FORMAT_SEQUENTIAL  = "Phylip S";  
+const string IoSequenceFactory::PAML_FORMAT_INTERLEAVED   = "PAML I";  
+const string IoSequenceFactory::PAML_FORMAT_SEQUENTIAL    = "PAML S";  
+const string IoSequenceFactory::GENBANK_FORMAT            = "GenBank";  
+const string IoSequenceFactory::NEXUS_FORMAT              = "Nexus";  
 
-ISequence* IOSequenceFactory::createReader(const string& format) throw (Exception)
+ISequence* IoSequenceFactory::createReader(const string& format) throw (Exception)
 {
        if(format == FASTA_FORMAT) return new Fasta();
   else if(format == MASE_FORMAT) return new Mase();
+  else if(format == CLUSTAL_FORMAT) return new Clustal();
   else if(format == DCSE_FORMAT) return new DCSE();
   else if(format == PHYLIP_FORMAT_INTERLEAVED) return new Phylip(false, false);
   else if(format == PHYLIP_FORMAT_SEQUENTIAL) return new Phylip(false, true);
@@ -64,12 +72,14 @@ ISequence* IOSequenceFactory::createReader(const string& format) throw (Exceptio
   else if(format == PAML_FORMAT_SEQUENTIAL) return new Phylip(true, true);
   else if(format == GENBANK_FORMAT) return new GenBank();
   else if(format == NEXUS_FORMAT) return new NexusIOSequence();
-  else throw Exception("Format " + format + " is not supported for input.");
+  else throw Exception("Format " + format + " is not supported for sequences input.");
 }
   
-IAlignment* IOSequenceFactory::createAlignmentReader(const string& format) throw (Exception)
+IAlignment* IoSequenceFactory::createAlignmentReader(const string& format) throw (Exception)
 {
-       if(format == CLUSTAL_FORMAT) return new Clustal();
+       if(format == FASTA_FORMAT) return new Fasta();
+  else if(format == MASE_FORMAT) return new Mase();
+  else if(format == CLUSTAL_FORMAT) return new Clustal();
   else if(format == DCSE_FORMAT) return new DCSE();
   else if(format == PHYLIP_FORMAT_INTERLEAVED) return new Phylip(false, false);
   else if(format == PHYLIP_FORMAT_SEQUENTIAL) return new Phylip(false, true);
@@ -79,14 +89,14 @@ IAlignment* IOSequenceFactory::createAlignmentReader(const string& format) throw
   else throw Exception("Format " + format + " is not supported for alignment input.");
 }
   
-OSequence* IOSequenceFactory::createWriter(const string& format) throw (Exception)
+OSequence* IoSequenceFactory::createWriter(const string& format) throw (Exception)
 {
        if(format == FASTA_FORMAT) return new Fasta();
   else if(format == MASE_FORMAT) return new Mase();
   else throw Exception("Format " + format + " is not supported for output.");
 }
 
-OAlignment* IOSequenceFactory::createAlignmentWriter(const string& format) throw (Exception)
+OAlignment* IoSequenceFactory::createAlignmentWriter(const string& format) throw (Exception)
 {
        if (format == FASTA_FORMAT) return new Fasta();
   else if (format == MASE_FORMAT) return new Mase();
