@@ -42,6 +42,7 @@ knowledge of the CeCILL license and that you accept its terms.
 #define _MASE_H_
 
 #include "AbstractISequence.h"
+#include "AbstractIAlignment.h"
 #include "AbstractOSequence.h"
 #include "../Sequence.h"
 #include "../Container/SequenceContainer.h"
@@ -61,17 +62,17 @@ class MaseHeader
 {
   private:
     mutable std::map<std::string, std::string> trees_;
-    mutable std::map<std::string, MultiRange<unsigned int> > siteSelections_;
-    mutable std::map<std::string, std::vector<unsigned int> > sequenceSelections_;
+    mutable std::map<std::string, MultiRange<size_t> > siteSelections_;
+    mutable std::map<std::string, std::vector<size_t> > sequenceSelections_;
 
   public:
     MaseHeader(): trees_(), siteSelections_(), sequenceSelections_() {}
     virtual ~MaseHeader() {}
 
   public:
-    unsigned int getNumberOfTrees() const { return trees_.size(); }
-    unsigned int getNumberOfSiteSelections() const { return siteSelections_.size(); }
-    unsigned int getNumberOfSequenceSelections() const { return sequenceSelections_.size(); }
+    size_t getNumberOfTrees() const { return trees_.size(); }
+    size_t getNumberOfSiteSelections() const { return siteSelections_.size(); }
+    size_t getNumberOfSequenceSelections() const { return sequenceSelections_.size(); }
 
     std::vector<std::string> getTreeNames() const { return MapTools::getKeys(trees_); }
     std::vector<std::string> getSiteSelectionNames() const { return MapTools::getKeys(siteSelections_); }
@@ -84,14 +85,14 @@ class MaseHeader
         throw Exception("MaseHeader::getTree. No tree with name " + name);
       }
     }
-    const MultiRange<unsigned int>& getSiteSelection(const std::string& name) const throw (Exception) {
+    const MultiRange<size_t>& getSiteSelection(const std::string& name) const throw (Exception) {
       if (siteSelections_.find(name) != siteSelections_.end()) {
         return siteSelections_[name];
       } else {
         throw Exception("MaseHeader::getSiteSelection. No site selection with name " + name);
       }
     }
-    const std::vector<unsigned int>& getSequenceSelection(const std::string& name) const throw (Exception) {
+    const std::vector<size_t>& getSequenceSelection(const std::string& name) const throw (Exception) {
       if (sequenceSelections_.find(name) != sequenceSelections_.end()) {
         return sequenceSelections_[name];
       } else {
@@ -102,10 +103,10 @@ class MaseHeader
     void setTree(const std::string& name, const std::string& tree) {
       trees_[name] = tree;
     }
-    void setSiteSelection(const std::string& name, const MultiRange<unsigned int>& ranges) {
+    void setSiteSelection(const std::string& name, const MultiRange<size_t>& ranges) {
       siteSelections_[name] = ranges;
     }
-    void setSequenceSelection(const std::string& name, const std::vector<unsigned int>& set) {
+    void setSequenceSelection(const std::string& name, const std::vector<size_t>& set) {
       sequenceSelections_[name] = set;
     }
 
@@ -123,6 +124,7 @@ class MaseHeader
  */
 class Mase:
   public AbstractISequence,
+  public AbstractIAlignment,
   public AbstractOSequence
 {
 
@@ -156,7 +158,7 @@ class Mase:
     VectorSequenceContainer* readMeta(std::istream& input, const Alphabet* alpha, MaseHeader& header) const throw (Exception)
     {
       readHeader_(input, header);
-      return AbstractISequence::read(input, alpha);
+      return AbstractISequence::readSequences(input, alpha);
     }
     VectorSequenceContainer* readMeta(std::string& path, const Alphabet* alpha, MaseHeader& header) const throw (Exception)
     {
@@ -172,18 +174,29 @@ class Mase:
      *
      * @{
      */
-    void appendFromStream(std::istream& input, SequenceContainer& sc) const throw (Exception);
+    void appendSequencesFromStream(std::istream& input, SequenceContainer& sc) const throw (Exception);
     /** @} */
 
+    /**
+     * @name The AbstractIAlignment interface.
+     *
+     * @{
+     */
+    void appendAlignmentFromStream(std::istream& input, SiteContainer& sc) const throw (Exception) {
+      appendSequencesFromStream(input, sc); //This might cast an exception if sequences are not aligned! 
+    }
+    /** @} */
+
+
     /**
      * @name The OSequence interface.
      *
      * @{
      */
-    void write(std::ostream& output, const SequenceContainer& sc) const throw (Exception);
-    void write(const std::string& path, const SequenceContainer& sc, bool overwrite = true) const throw (Exception)
+    void writeSequences(std::ostream& output, const SequenceContainer& sc) const throw (Exception);
+    void writeSequences(const std::string& path, const SequenceContainer& sc, bool overwrite = true) const throw (Exception)
     {
-      AbstractOSequence::write(path, sc, overwrite);
+      AbstractOSequence::writeSequences(path, sc, overwrite);
     }
     /** @} */
 
@@ -195,14 +208,14 @@ class Mase:
     void writeMeta(std::ostream& output, const SequenceContainer& sc, const MaseHeader& header) const throw (Exception)
     {
       writeHeader_(output, header);
-      write(output, sc);
+      writeSequences(output, sc);
     }
     void writeMeta(const std::string& path, const SequenceContainer& sc, const MaseHeader& header, bool overwrite = true) const throw (Exception)
     {
 			// Open file in specified mode
       std::ofstream output(path.c_str(), overwrite ? (std::ios::out) : (std::ios::out | std::ios::app));
       writeHeader_(output, header);
-			write(output, sc);
+			writeSequences(output, sc);
 			output.close();
     }
     /** @} */
