@@ -5,7 +5,7 @@
 //
 
 /*
-Copyright or © or Copr. CNRS, (November 17, 2004)
+Copyright or © or Copr. Bio++ Development Team, (November 17, 2004)
 
 This software is a computer program whose purpose is to provide classes
 for sequences analysis.
@@ -171,7 +171,7 @@ void Phylip::readInterleaved(std::istream& in, SiteContainer& asc) const throw (
   
 /******************************************************************************/
 
-void Phylip::appendFromStream(std::istream& input, SiteContainer& vsc) const throw (Exception)
+void Phylip::appendAlignmentFromStream(std::istream& input, SiteContainer& vsc) const throw (Exception)
 {
   // Checking the existence of specified file
   if (!input) { throw IOException ("Phylip::read: fail to open file"); }
@@ -205,11 +205,11 @@ std::vector<std::string> Phylip::getSizedNames(const std::vector<std::string>& n
   {
     //Add 6 white spaces to the larger name and align other names.
     //First, determine the size of the wider name:
-    unsigned int sizeMax = 0;
-    for (unsigned int i = 0; i < names.size(); i++)
-      if(names[i].size() > sizeMax) sizeMax = names[i].size();
+    size_t sizeMax = 0;
+    for (size_t i = 0; i < names.size(); i++)
+      if (names[i].size() > sizeMax) sizeMax = names[i].size();
     //Quite easy ;-) Now update all lengths:
-    for (unsigned int i = 0; i < names.size(); i++)
+    for (size_t i = 0; i < names.size(); i++)
       sizedNames[i] = TextTools::resizeRight(names[i], sizeMax) + namesSplit_;  
   }
   else
@@ -226,12 +226,12 @@ std::vector<std::string> Phylip::getSizedNames(const std::vector<std::string>& n
 void Phylip::writeSequential(std::ostream& out, const SequenceContainer& sc, int charsByLine) const
 {
   //cout << "Write sequential" << endl;
-  int numberOfSites = sc.getSequence(sc.getSequencesNames()[0]).size() * sc.getAlphabet()->getStateCodingSize();
+  size_t numberOfSites = sc.getSequence(sc.getSequencesNames()[0]).size() * sc.getAlphabet()->getStateCodingSize();
   out << sc.getNumberOfSequences() << " " << numberOfSites << endl;
   
   vector<string> seqNames = sc.getSequencesNames();
   vector<string> names = getSizedNames(seqNames);
-  for (unsigned int i = 0; i < seqNames.size(); i++)
+  for (size_t i = 0; i < seqNames.size(); i++)
   {
     vector<string> seq = TextTools::split(sc.toString(seqNames[i]), charsByLine);
     out << names[i] << seq[0] << endl;
@@ -246,25 +246,25 @@ void Phylip::writeSequential(std::ostream& out, const SequenceContainer& sc, int
 void Phylip::writeInterleaved(std::ostream& out, const SequenceContainer& sc, int charsByLine) const
 {
   //cout << "Write interleaved;" << endl;
-  int numberOfSites = sc.getSequence(sc.getSequencesNames()[0]).size() * sc.getAlphabet()->getStateCodingSize();
+  size_t numberOfSites = sc.getSequence(sc.getSequencesNames()[0]).size() * sc.getAlphabet()->getStateCodingSize();
   out << sc.getNumberOfSequences() << " " << numberOfSites << endl;
   
   vector<string> seqNames = sc.getSequencesNames();
   vector<string> names = getSizedNames(seqNames);
   //Split sequences:
   vector< vector<string> > seqs(sc.getNumberOfSequences());
-  for (unsigned int i = 0; i < seqNames.size(); i++)
+  for (size_t i = 0; i < seqNames.size(); i++)
   {
     seqs[i] = TextTools::split(sc.toString(seqNames[i]), charsByLine);
   }
   //Write first block:
-  for (unsigned int i = 0; i < names.size(); i++)
+  for (size_t i = 0; i < names.size(); i++)
   {
     out << names[i] << seqs[i][0] << endl;
   }
   out << endl;
   //Write other blocks:
-  for (unsigned int j = 1; j < seqs[0].size(); j++)
+  for (size_t j = 1; j < seqs[0].size(); j++)
   {
     for (unsigned int i = 0; i < sc.getNumberOfSequences(); i++)
     {
@@ -276,15 +276,12 @@ void Phylip::writeInterleaved(std::ostream& out, const SequenceContainer& sc, in
 
 /******************************************************************************/
 
-void Phylip::write(std::ostream& output, const SiteContainer& sc) const throw (Exception)
+void Phylip::writeAlignment(std::ostream& output, const SiteContainer& sc) const throw (Exception)
 {
   //First must check if all sequences are aligned:
   if (sc.getNumberOfSequences() == 0)
     throw Exception("Phylip::write. SequenceContainer appear to contain no sequence.");
   
-  if (!SequenceContainerTools::sequencesHaveTheSameLength(sc))
-    throw SequenceNotAlignedException("Phylip::write. Sequences have to e of same length.", NULL);
-  
   // Checking the existence of specified file, and possibility to open it in write mode
   if (!output) { throw IOException ("Phylip::write : failed to open file"); }
 
