@@ -37,8 +37,9 @@ The fact that you are presently reading this means that you have had
 knowledge of the CeCILL license and that you accept its terms.
 */
 
-#include <Bpp/Seq/Alphabet.all>
-#include <Bpp/Seq/Container.all>
+#include <Bpp/Seq/Alphabet/RNA.h>
+#include <Bpp/Seq/Container/VectorSiteContainer.h>
+#include <Bpp/Seq/Container/SiteContainerTools.h>
 #include <iostream>
 
 using namespace bpp;
